#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.4
visibility:           public
id:                   adjunctions-4.4.4-G5WQRfPbSRGCKNKHZiFSpV
key:                  adjunctions-4.4.4-G5WQRfPbSRGCKNKHZiFSpV
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  f99bdaad04251f29338ba89a5642d8c5
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/adjunctions-4.4.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.4-G5WQRfPbSRGCKNKHZiFSpV
depends:
    base-4.18.2.1 comonad-5.0.10-LqxoFDNdGVFJLLfgnMWNt2
    containers-0.6.7 distributive-0.6.2.1-5eqx3SfIS8dLTyZdD1ANMz
    free-5.2-DaHCx1lHPp4c1iLjoTi4v mtl-2.3.1
    profunctors-5.6.3-C2kOGoQfc8x5B5shbEWu9Z
    semigroupoids-6.0.2-1WxeLhxLtrhK9J3g7bTF0t
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

